@@ -21,7 +21,7 @@ commands = {
         'register': Command(unavailiable_in_context),
         'unregister': Command(unavailiable_in_context),
         'help': Command(help_text, help_text="Show this help."),
-        'start': Command(help_text, help_text="Makes me sneak into your DMs."),
+        'start': Command(start, help_text="Makes me sneak into your DMs."),
     },
     DiscordContext.DM_CHANNEL: {
         'register': Command(register,
@@ -30,7 +30,7 @@ commands = {
                             "THROUGH THE INTERNET WHEN LOGGING IN THE MINECRAFT SERVER!"),
         'unregister': Command(unregister,
                               "Unregister your Minecraft player. Type the player name as a confirmation."),
-        'help': Command(start, help_text="Show this help."),
+        'help': Command(help_text, help_text="Show this help."),
     },
     DiscordContext.GROUP_CHANNEL: {
         'register': Command(unavailiable_in_context),
